*CTTITEM_D conducts item analysis for dichotomous data
*It produces total score distribution statistics, reliability statistics,
*p-value, D-index. Distractor analysis is also available for dichotomous 
*variables. All the changes that you need to make to this syntax to fit 
*into your own data structure have been prompted within the syntax and in 
*the manual. Pay attention to the setence behind '*'.

*INPUT DATA SPECIFICATIOIN
*text format.
*First line: correct options
*Start from second line: examinee responses with each line representing one case
*Use space to indicate missing value

*SYNTAX CHANGE
*File locations--'C:\temp. Most of the changes are in file locations. An easy way is
  *to use the "replace all" function under the "Edit" menu, and replace all the "C:\temp"
  *with your designated location.
*Variable names--MC1 TO MC15. Change them to your own item names.


***************************************************************************************.
*Specify the file location and file name for your own original dataset.
*Name your items and change 'MC1 TO MC15' accordingly. If items 
   *are not named consecutively, specify the names seperately.
*'1-15' indicate the location of the variables in your dataset, change that accordingly.
******************************************************************************************.
DATA LIST FILE='C:\temp\MC.TXT'
   / MC1 TO MC15 1-15.

MISSING VALUES ALL ( ).

SET MXLOOPS=300 /MPRINT=NO.

*****************************************************************************.
*Change variable names, be consistent with the previous statement.
*****************************************************************************.
MATRIX.
GET RAW
  /VARIABLES=MC1 TO MC15 
  /FILE=* 
  /MISSING=ACCEPT
  /SYSMIS=-9.

COMPUTE NCASE=NROW(RAW)-1.
COMPUTE NITEM=NCOL(RAW).
COMPUTE SCORE=MAKE(NCASE,NITEM,0).
COMPUTE RAWN=MAKE(NCASE,NITEM,0).

/*******SCORING ITEMS***********************/


LOOP N=2 TO NROW(RAW).
- LOOP I=1 TO NITEM.
-  DO IF(RAW(N,I)=RAW(1,I)).
-  COMPUTE SCORE((N-1),I)=1.
  ELSE.
- COMPUTE SCORE((N-1),I)=0.
- END IF.
-END LOOP.
END LOOP.

LOOP N=2 TO NROW(RAW).
- LOOP I=1 TO NITEM.
-  COMPUTE RAWN((N-1),I)=RAW(N,I).
-END LOOP.
END LOOP.

/******COMPUTE TOTAL SCORE********/
**************************************************************************.
*Change file location('C:\temp) in the following several statements.
*You are recommended to put all datasets under the same directory.
***************************************************************************.
COMPUTE TOTSC=RSUM(SCORE).
SAVE TOTSC
/OUTFILE='C:\temp\TOTSCORE.SAV'
/VARIABLES=TOTSC.

**********************************************************************************************.
*Change variable names 'MC1 TO MC15', be consistent with previous statements.
**********************************************************************************************.

SAVE SCORE
/OUTFILE='C:\temp\ITEMSCORE.SAV'
/VARIABLES=MC1 TO MC15.

COMPUTE R=GRADE(TOTSC).
COMPUTE RSC={R,TOTSC}.

COMPUTE GRP=MAKE(NCASE,1,0).

COMPUTE #LOW=0.
COMPUTE LOWCUT=0.

LOOP I=1 TO NCASE.
-DO IF(RSC(I,1)/NCASE<=0.27) AND (LOWCUT<RSC(I,2)).
  COMPUTE LOWCUT=RSC(I,2).
  ELSE.
-END IF.
END LOOP.

LOOP I=1 TO NCASE.
-DO IF(RSC(I,2)<=LOWCUT).
-COMPUTE #LOW=#LOW+1.
-COMPUTE GRP(I,1)=3.
 ELSE.
-END IF.
END LOOP.

COMPUTE UPCUT=NITEM.

LOOP I=1 TO NCASE.
-DO IF(RSC(I,1)/NCASE>=0.73) AND (UPCUT>RSC(I,2)).
  COMPUTE UPCUT=RSC(I,2).
  ELSE.
-END IF.
END LOOP.

COMPUTE #UP=0.

LOOP I=1 TO NCASE.
-DO IF(RSC(I,2)>=UPCUT).
- COMPUTE GRP(I,1)=1.
- COMPUTE #UP=#UP+1.
  ELSE.
-END IF.
END LOOP.

***************************************************************************.
*Change file location 'C:\temp and variable names 'MC1 to MC15'.
*Be consistent with previous statements.
**************************************************************************.
COMPUTE RAWGRP={GRP,RAWN}.
SAVE RAWGRP
/OUTFILE='C:\temp\RAWGRP.SAV'
/VARIABLES=GRP MC1 TO MC15.

COMPUTE ITEMGRP={GRP,SCORE}. 
COMPUTE DINDEX=MAKE(NITEM,1,-9).
COMPUTE TOHI=MAKE(NITEM,1,0).
COMPUTE TOLO=MAKE(NITEM,1,0).

LOOP I=1 TO NITEM.
-LOOP N=1 TO NCASE.
-DO IF(ITEMGRP(N,1)=1).
-      COMPUTE TOHI(I,1)=ITEMGRP(N,I+1)+TOHI(I,1).
-ELSE.
-END IF.
-END LOOP.
END LOOP.


LOOP I=1 TO NITEM.
-LOOP N=1 TO NCASE.
-DO IF(ITEMGRP(N,1)=3).
-        COMPUTE TOLO(I,1)=ITEMGRP(N,I+1)+TOLO(I,1).
-ELSE.
-END IF.
-END LOOP.
END LOOP.

COMPUTE DINDEX=TOHI/#UP-TOLO/#LOW.
COMPUTE PVALUET=CSUM(SCORE)/NCASE.
COMPUTE PVALUE=TRANSPOS(PVALUET).

COMPUTE PD={PVALUE,DINDEX}.

**********************************.
*Change file location 'C:\temp.
**********************************.

SAVE PD
 /OUTFILE='C:\temp\PD.SAV'
 /VARIABLES=PVALUE D_INDEX.

END MATRIX.


********************************************************************************************************************************************
********************************************************************************************************************************************

**********************************.
*Change file location 'C:\temp.
**********************************.
GET FILE='C:\temp\TOTSCORE.SAV'.
TITLE '************************************************************'.
TITLE '***TEST STATISTICS--TOTAL SCORE DISTRIBUTION***'.
TITLE '************************************************************'.
EXECUTE.
VARIABLE LABELS
TOTSC 'TOTAL SCORE'.

DESCRIPTIVES
  VARIABLES=TOTSC
  /STATISTICS=MEAN STDDEV MIN MAX SKEWNESS KURTOSIS.
EXECUTE.

**********************************.
*Change file location 'C:\temp.
**********************************.
GET FILE='C:\temp\ITEMSCORE.SAV'.
TITLE '****************************************************'.
TITLE '******RELIABILITY ANALYSIS********************'.
TITLE '****************************************************'.
EXECUTE.
RELIABILITY
  /VARIABLES=ALL
  /FORMAT=NOLABELS
  /SCALE(ALPHA)=ALL/MODEL=ALPHA
  /SUMMARY=TOTAL CORR.
EXECUTE.

**********************************.
*Change file location 'C:\temp.
**********************************.
GET FILE='C:\temp\PD.SAV'.
TITLE '*********************************************************'.
TITLE '********P VALUE AND DISCRIMINATION INDEX******'.
TITLE '*********************************************************'.
EXECUTE.
COMPUTE ITEM_NUM=$CASENUM.
FORMAT ITEM_NUM (F5.0).

LIST VARIABLES=ITEM_NUM PVALUE D_INDEX.
EXECUTE.

**********************************.
*Change file location 'C:\temp.
**********************************.
GET FILE='C:\temp\RAWGRP.SAV'.
TITLE '********************************************************'.
TITLE '********DISTRACTOR ANALYSIS*********************'.
TITLE '********************************************************'.
EXECUTE.

VARIABLE LABELS
GRP 'GROUP'.

VALUE LABELS
GRP 1 'HIGH' 3 'LOW'.

USE ALL.
COMPUTE filter_$=(GRP>0).
VARIABLE LABEL filter_$ 'GRP>0 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

FORMAT ALL (F1.0).

MISSING VALUE ALL (-9).

****************************************************************.
*Change variable names:list all your item names after "BY"
*The abbreviated form "MC1 to MC15" does not work here.
*****************************************************************.
CROSSTABS
  /TABLES=GRP  BY MC1 MC2 MC3 MC4 MC5 MC6 MC7 MC8 MC9 MC10 MC11 MC12 MC13 MC14 MC15 
  /FORMAT= AVALUE TABLES
  /CELLS= COUNT
  /COUNT ROUND CELL.